==> jc-1.4.0.tar.gz: javax/xml/xpath/XPathFunctionException.h <==
// public class javax.xml.xpath.XPathFunctionException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class bf48a3b3cd7f380d javax_xml_xpath_XPathException
// @dep_class 22385819c46ef7f2 javax_xml_xpath_XPathExpressionException
// @dep_class f21840602c4a8200 javax_xml_xpath_XPathFunctionException

// header file dependencies
// @dep_header javax_xml_xpath_XPathExpressionException

#include "javax/xml/xpath/XPathExpressionException.h"

#ifndef _JC_javax_xml_xpath_XPathFunctionException_H_
#define _JC_javax_xml_xpath_XPathFunctionException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_javax_xml_xpath_XPathFunctionException$sub_refs	_jc_javax_xml_xpath_XPathFunctionException$sub_refs;
typedef struct _jc_javax_xml_xpath_XPathFunctionException$sub_nonrefs	_jc_javax_xml_xpath_XPathFunctionException$sub_nonrefs;
typedef struct _jc_javax_xml_xpath_XPathFunctionException$refs	_jc_javax_xml_xpath_XPathFunctionException$refs;
typedef struct _jc_javax_xml_xpath_XPathFunctionException$nonrefs	_jc_javax_xml_xpath_XPathFunctionException$nonrefs;
typedef struct _jc_javax_xml_xpath_XPathFunctionException$object	_jc_javax_xml_xpath_XPathFunctionException$object;

typedef const struct _jc_javax_xml_xpath_XPathFunctionException$vmethods	_jc_javax_xml_xpath_XPathFunctionException$vmethods;
typedef const struct _jc_javax_xml_xpath_XPathFunctionException$vtable	_jc_javax_xml_xpath_XPathFunctionException$vtable;
typedef const struct _jc_javax_xml_xpath_XPathFunctionException$vtype	_jc_javax_xml_xpath_XPathFunctionException$vtype;

// Constructors
extern void _jc_javax_xml_xpath_XPathFunctionException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_xml_xpath_XPathFunctionException$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_xml_xpath_XPathFunctionException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_javax_xml_xpath_XPathFunctionException$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods structure
struct _jc_javax_xml_xpath_XPathFunctionException$vmethods {
};

// Vtable
struct _jc_javax_xml_xpath_XPathFunctionException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_xml_xpath_XPathException$vmethods	javax_xml_xpath_XPathException;
	_jc_javax_xml_xpath_XPathExpressionException$vmethods	javax_xml_xpath_XPathExpressionException;
	_jc_javax_xml_xpath_XPathFunctionException$vmethods	javax_xml_xpath_XPathFunctionException;
};

// Vtype
struct _jc_javax_xml_xpath_XPathFunctionException$vtype {
	_jc_type			type;
	_jc_javax_xml_xpath_XPathFunctionException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_xpath_XPathFunctionException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_xpath_XPathFunctionException$refs {
    _jc_javax_xml_xpath_XPathFunctionException$sub_refs	javax_xml_xpath_XPathFunctionException;
    _jc_javax_xml_xpath_XPathExpressionException$sub_refs	javax_xml_xpath_XPathExpressionException;
    _jc_javax_xml_xpath_XPathException$sub_refs	javax_xml_xpath_XPathException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_xpath_XPathFunctionException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_xpath_XPathFunctionException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_xml_xpath_XPathException$sub_nonrefs	javax_xml_xpath_XPathException;
    _jc_javax_xml_xpath_XPathExpressionException$sub_nonrefs	javax_xml_xpath_XPathExpressionException;
    _jc_javax_xml_xpath_XPathFunctionException$sub_nonrefs	javax_xml_xpath_XPathFunctionException;
};

// Object instance structure
struct _jc_javax_xml_xpath_XPathFunctionException$object {
	_jc_javax_xml_xpath_XPathFunctionException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_xpath_XPathFunctionException$vtype	*vtype;
	_jc_javax_xml_xpath_XPathFunctionException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_xpath_XPathFunctionException$vtype _jc_javax_xml_xpath_XPathFunctionException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_xpath_XPathFunctionException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_xpath_XPathFunctionException$class_object;

#endif	/* _JC_javax_xml_xpath_XPathFunctionException_H_ */

==> jc-1.4.6.tar.gz: javax/xml/xpath/XPathFunctionException.h <==
// public class javax.xml.xpath.XPathFunctionException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class bf48a3b3cd7f380d javax_xml_xpath_XPathException
// @dep_class 22385819c46ef7f2 javax_xml_xpath_XPathExpressionException
// @dep_class f21840602c4a8200 javax_xml_xpath_XPathFunctionException

// header file dependencies
// @dep_header javax_xml_xpath_XPathExpressionException

#include "javax/xml/xpath/XPathExpressionException.h"

#ifndef _JC_javax_xml_xpath_XPathFunctionException_H_
#define _JC_javax_xml_xpath_XPathFunctionException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_javax_xml_xpath_XPathFunctionException$sub_refs	_jc_javax_xml_xpath_XPathFunctionException$sub_refs;
typedef struct _jc_javax_xml_xpath_XPathFunctionException$sub_nonrefs	_jc_javax_xml_xpath_XPathFunctionException$sub_nonrefs;
typedef struct _jc_javax_xml_xpath_XPathFunctionException$refs	_jc_javax_xml_xpath_XPathFunctionException$refs;
typedef struct _jc_javax_xml_xpath_XPathFunctionException$nonrefs	_jc_javax_xml_xpath_XPathFunctionException$nonrefs;
typedef struct _jc_javax_xml_xpath_XPathFunctionException$object	_jc_javax_xml_xpath_XPathFunctionException$object;

typedef const struct _jc_javax_xml_xpath_XPathFunctionException$vmethods	_jc_javax_xml_xpath_XPathFunctionException$vmethods;
typedef const struct _jc_javax_xml_xpath_XPathFunctionException$vtable	_jc_javax_xml_xpath_XPathFunctionException$vtable;
typedef const struct _jc_javax_xml_xpath_XPathFunctionException$vtype	_jc_javax_xml_xpath_XPathFunctionException$vtype;

// Constructors
extern void _jc_javax_xml_xpath_XPathFunctionException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_xml_xpath_XPathFunctionException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_xpath_XPathFunctionException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_javax_xml_xpath_XPathFunctionException$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_xml_xpath_XPathFunctionException$vmethods {
};

// Vtable
struct _jc_javax_xml_xpath_XPathFunctionException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_xml_xpath_XPathException$vmethods	javax_xml_xpath_XPathException;
	_jc_javax_xml_xpath_XPathExpressionException$vmethods	javax_xml_xpath_XPathExpressionException;
	_jc_javax_xml_xpath_XPathFunctionException$vmethods	javax_xml_xpath_XPathFunctionException;
};

// Vtype
struct _jc_javax_xml_xpath_XPathFunctionException$vtype {
	_jc_type			type;
	_jc_javax_xml_xpath_XPathFunctionException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_xpath_XPathFunctionException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_xpath_XPathFunctionException$refs {
    _jc_javax_xml_xpath_XPathFunctionException$sub_refs	javax_xml_xpath_XPathFunctionException;
    _jc_javax_xml_xpath_XPathExpressionException$sub_refs	javax_xml_xpath_XPathExpressionException;
    _jc_javax_xml_xpath_XPathException$sub_refs	javax_xml_xpath_XPathException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_xpath_XPathFunctionException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_xpath_XPathFunctionException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_xml_xpath_XPathException$sub_nonrefs	javax_xml_xpath_XPathException;
    _jc_javax_xml_xpath_XPathExpressionException$sub_nonrefs	javax_xml_xpath_XPathExpressionException;
    _jc_javax_xml_xpath_XPathFunctionException$sub_nonrefs	javax_xml_xpath_XPathFunctionException;
};

// Object instance structure
struct _jc_javax_xml_xpath_XPathFunctionException$object {
	_jc_javax_xml_xpath_XPathFunctionException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_xpath_XPathFunctionException$vtype	*vtype;
	_jc_javax_xml_xpath_XPathFunctionException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_xpath_XPathFunctionException$vtype _jc_javax_xml_xpath_XPathFunctionException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_xpath_XPathFunctionException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_xpath_XPathFunctionException$class_object;

#endif	/* _JC_javax_xml_xpath_XPathFunctionException_H_ */
